# Kable Python Django SDK

Welcome to **[Kable](https://dev.kableapi.com)**! Kable is the best solution for API products to manage authentication, permissions, and billing.

This SDK is the best way to integrate Kable into your Python (Django) application. For documentation and detailed instructions about how to use this SDK, please visit https://kable.stoplight.io/docs/kable.

Note: If you use Flask instead of Django, please download our [Flask SDK](https://pypi.org/project/kable-python-flask) instead.

**[Kable](https://dev.kableapi.com)** | https://dev.kableapi.com/